Welcome to the User Guide of the napari-boxmanager!
==================================

Welcome, this is the user guide for the napari-boxmanager!


User Guide: full table of contents
==================================

.. toctree::
   :maxdepth: 2

   manual/manual
   changes


Help
====

Any questions? Problems? Suggestions?

Find help at our `mailing list <https://listserv.gwdg.de/mailman/listinfo/sphire>`_ or `open an issue on GitHub <https://github.com/MPI-Dortmund/napari-boxmanager>`_!
